==> UPS-courier_v1.3.4.zip: UPS-courier v1.3.4/UPS-courier v1.3.4.oxp/scripts/upsMidair.js <==
/*this.name      = "upsMidair"; 
this.author    = "eric walch"; 
this.copyright = " 2008 the Oolite team."; 
this.version   = "1.00"; */

this.shipSpawned = function() {this.traderFlewIn();}

this.traderFlewIn = function()
{
    ship.switchAI("midairUpsJSAI.plist");
    this.collissionradius = 100
    this.shipName = ""
    this.countdown = 5
    delete this.shipSpawned;
    delete this.traderFlewIn;
}

this.checkDistance = function()
{
  let distance = Math.round(player.position.distanceTo(this.ship))
  if (distance < 6000)
  {
  player.consoleMessage("You are on approach, lower your speed", 9)
  this.shipName = this.ship.shipDescription
  this.ship.shipDescription = this.shipName + " with packages"
  this.ship.AIState = "APPROACH";
  }
}

this.guideIn = function()
{
    let distance = Math.round(player.position.distanceTo(this.ship)) - this.collissionradius
    let speed = Math.round(player.speed)
    if (distance > 1500)
    {
        if(speed > 100) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed.", 5)
    }
    else
    {
        if(speed > 50) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed to 50 km/h.", 5)
        player.consoleMessage("You are at " + distance + " meters, come to a complete standstill within 100 meters.", 5)
    }
    if(distance < 100 && player.speed == 0)
    {
    this.ship.AIState = "WAIT_FOR_DELIVERY";
    }
}

this.checkSpeed = function()
{
  if (player.speed > 5)
  {
    player.consoleMessage("You are moving to much, lower your speed", 5)
    this.ship.AIState = "APPROACH";
    this.countdown = 5
  }
  else
  {
    player.consoleMessage("Transfering parcels..... " +this.countdown, 3)
    this.countdown--
    if(this.countdown<0)
    {
        this.ship.AIState = "TRANSFER_PACKAGE"
    }
  }
}

this.transfer_package = function()
{
    player.consoleMessage("Make room or you will be sucked in my wormhole... ", 8)
    missionVariables.ups_parcel = "MIDAIR"
    player.call("checkScript") // remove this in 1.71
    this.ship.shipDescription = this.shipName + " without packages"
/*    //activate this in Oolite version 1.71 and take he tickle_eveny out of ups_parcel.
    missionVariables.ups_pplanetname = ExpandDescription("[%H]") 
    missionVariables.ups_pplanet = system.ID
    missionVariables.ups_parcel_appearance = ExpandDescription("[ups_numbers]") + " " + ExpandDescription("[ups_colors]") + " " + ExpandDescription("[%I]")
    mission.setInstructionsKey("ups_parcel_midair", "worldScripts.ups_parcel")
    mission.markSystem(system.ID)
    missionVariables.ups_parcel == "MIDAIR_DELIVERY"
*/  
}

==> UPS-courier_v1.3.6.zip: UPS-courier v1.3.6/UPS-courier v1.3.6.oxp/scripts/upsMidair.js <==
/*this.name      = "upsMidair"; 
this.author    = "eric walch"; 
this.copyright = " 2008 the Oolite team."; 
this.version   = "1.00"; */

this.shipSpawned = function() {this.traderFlewIn();}

this.traderFlewIn = function()
{
    ship.switchAI("midairUpsJSAI.plist");
    this.collissionradius = 100
    this.shipName = ""
    this.countdown = 5
    delete this.shipSpawned;
    delete this.traderFlewIn;
}

this.checkDistance = function()
{
  let distance = Math.round(player.position.distanceTo(this.ship))
  if (distance < 6000)
  {
  player.consoleMessage("You are on approach, lower your speed", 9)
  this.shipName = this.ship.shipDescription
  this.ship.shipDescription = this.shipName + " with packages"
  this.ship.AIState = "APPROACH";
  }
}

this.guideIn = function()
{
    let distance = Math.round(player.position.distanceTo(this.ship)) - this.collissionradius
    let speed = Math.round(player.speed)
    if (distance > 1500)
    {
        if(speed > 100) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed.", 5)
    }
    else
    {
        if(speed > 50) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed to 50 km/h.", 5)
        player.consoleMessage("You are at " + distance + " meters, come to a complete standstill within 100 meters.", 5)
    }
    if(distance < 100 && player.speed == 0)
    {
    this.ship.AIState = "WAIT_FOR_DELIVERY";
    }
}

this.checkSpeed = function()
{
  if (player.speed > 5)
  {
    player.consoleMessage("You are moving to much, lower your speed", 5)
    this.ship.AIState = "APPROACH";
    this.countdown = 5
  }
  else
  {
    player.consoleMessage("Transfering parcels..... " +this.countdown, 3)
    this.countdown--
    if(this.countdown<0)
    {
        this.ship.AIState = "TRANSFER_PACKAGE"
    }
  }
}

this.transfer_package = function()
{
    player.consoleMessage("Make room or you will be sucked in my wormhole... ", 8)
    missionVariables.ups_parcel = "MIDAIR"
    player.call("checkScript") // remove this in 1.71
    this.ship.shipDescription = this.shipName + " without packages"
/*    //activate this in Oolite version 1.71 and take he tickle_eveny out of ups_parcel.
    missionVariables.ups_pplanetname = ExpandDescription("[%H]") 
    missionVariables.ups_pplanet = system.ID
    missionVariables.ups_parcel_appearance = ExpandDescription("[ups_numbers]") + " " + ExpandDescription("[ups_colors]") + " " + ExpandDescription("[%I]")
    mission.setInstructionsKey("ups_parcel_midair", "ups_parcel")
    mission.markSystem(system.ID)
    missionVariables.ups_parcel == "MIDAIR_DELIVERY"
*/  
}
